VersionStatus class

Constructors

VersionStatus({required String localVersion, required String storeVersion, required String storeLink, String? releaseNotes})

Properties

canUpdate bool
no setter
hashCode int
The hash code for this object.
no setterinherited
localVersion String
final
releaseNotes String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
storeVersion String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited